<?php

namespace FiloBlu\Flow\Block\Adminhtml\Inboundflow;

use Exception;
use FiloBlu\Flow\Model\ResourceModel\Inboundflow\Collection;
use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Widget\Grid\Extended;
use Magento\Backend\Helper\Data;
use Magento\Catalog\Model\Product;
use Magento\Framework\DataObject;
use Magento\Framework\Exception\LocalizedException;

/**
 * Class Grid
 * @package FiloBlu\Flow\Block\Adminhtml\Inboundflow
 */
class Grid extends Extended
{
    /**
     * @var Collection
     */
    protected $collection;

    /**
     * @param Context $context
     * @param Data $backendHelper
     * @param Collection $collection
     * @param array $data
     *
     * @SuppressWarnings(PHPMD.ExcessiveParameterList)
     */
    public function __construct(
        Context $context,
        Data $backendHelper,
        Collection $collection,
        array $data = []
    ) {
        $this->collection = $collection;
        parent::__construct($context, $backendHelper, $data);
    }

    /**
     * @return string
     */
    public function getGridUrl()
    {
        return $this->getUrl('flow/*/index', ['_current' => true]);
    }

    /**
     * @param Product|DataObject $row
     * @return string
     */
    public function getRowUrl($row)
    {
        return $this->getUrl(
           'flow/*/edit',
           ['store' => $this->getRequest()->getParam('store'), 'id' => $row->getId()]
       );
    }

    /**
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();

        $this->setId('productGrid');
        $this->setDefaultSort('id');
        $this->setDefaultDir('DESC');
        $this->setSaveParametersInSession(true);
        $this->setUseAjax(false);
    }

    /**
     * @return $this
     */
    protected function _prepareCollection()
    {
        try {
            $collection = $this->collection->load();
            $this->setCollection($collection);
            parent::_prepareCollection();
            return $this;
        } catch (Exception $e) {
            echo $e->getMessage();
            die;
        }
    }

    /**
     * @return Extended
     * @throws LocalizedException
     */
    protected function _prepareColumns()
    {
        $this->addColumn(
            'id',
            [
                'header' => __('ID'),
                'type' => 'number',
                'index' => 'id',
                'header_css_class' => 'col-id',
                'column_css_class' => 'col-id'
            ]
        );
        $this->addColumn(
            'id',
            [
                'header' => __('id'),
                'index' => 'id',
                'class' => 'id'
            ]
        );
        $this->addColumn(
            'name',
            [
                'header' => __('name'),
                'index' => 'name',
                'class' => 'name'
            ]
        );
        $this->addColumn(
            'flow',
            [
                'header' => __('flow'),
                'index' => 'flow',
                'class' => 'flow'
            ]
        );
        $this->addColumn(
            'type',
            [
                'header' => __('type'),
                'index' => 'type',
                'class' => 'type'
            ]
        );
        $this->addColumn(
            'channel',
            [
                'header' => __('channel'),
                'index' => 'channel',
                'class' => 'channel'
            ]
        );
        $this->addColumn(
            'priority',
            [
                'header' => __('priority'),
                'index' => 'priority',
                'class' => 'priority'
            ]
        );
        $this->addColumn(
            'status',
            [
                'header' => __('status'),
                'index' => 'status',
                'class' => 'status'
            ]
        );
        $this->addColumn(
            'retry',
            [
                'header' => __('retry'),
                'index' => 'retry',
                'class' => 'retry'
            ]
        );
        $this->addColumn(
            'receiving_time',
            [
                'header' => __('receiving_time'),
                'index' => 'receiving_time',
                'type' => 'datetime',
            ]
        );
        $this->addColumn(
            'action',
            [
                'header' => __('Action'),
                'type' => 'action',
                'getter' => 'getId',
                'actions' => [
                    [
                        'caption' => __('Download'),
                        'url' => [
                            'base' => 'flow/*/download',
                        ],
                        'field' => 'id'
                    ]
                ],
                'filter' => false,
                'sortable' => false,
                'index' => 'increment_id',
                'header_css_class' => 'col-action',
                'column_css_class' => 'col-action'
            ]
        );

        $block = $this->getLayout()->getBlock('grid.bottom.links');
        if ($block) {
            $this->setChild('grid.bottom.links', $block);
        }

        return parent::_prepareColumns();
    }

    /**
     * @return $this
     */
    protected function _prepareMassaction()
    {
        $this->setMassactionIdField('id');
        $this->getMassactionBlock()->setFormFieldName('id');

        $this->getMassactionBlock()->addItem(
            'delete',
            [
                'label' => __('Delete'),
                'url' => $this->getUrl('flow/*/massDelete'),
                'confirm' => __('Are you sure?')
            ]
        );
        return $this;
    }
}
